@@ -3,18 +3,13 @@ use strict;
 use warnings;
 use App::bif::Context;
 
-our $VERSION = '0.1.0_18';
+our $VERSION = '0.1.0_19';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
     my $db  = $ctx->dbw;
 
-    my $info =
-         $db->get_topic( $ctx->{id} )
-      || $db->get_update( $ctx->{id} )
-      || $ctx->get_project( $ctx->{id} )
-      || return $ctx->err( 'TopicNotFound',
-        'topic, update or project not found: ' . $ctx->{id} );
+    my $info = $db->get_update( $ctx->{id} ) || $ctx->get_topic( $ctx->{id} );
 
     if ( !$ctx->{force} ) {
         print "Nothing dropped (missing --force, -f)\n";
@@ -22,17 +17,9 @@ sub run {
     }
 
     if ( $info->{update_id} ) {
-
-        $db->xdo(
-            delete_from => 'updates',
-            where       => { id => $info->{update_id} },
-        );
-
-        $db->update_repo(
+        $ctx->update_repo(
             {
-                author  => $ctx->{user}->{name},
-                email   => $ctx->{user}->{email},
-                message => 'drop '
+                    message => 'drop '
                   . $info->{kind} . ' '
                   . $info->{id}
                   . ' update '
@@ -40,24 +27,26 @@ sub run {
             }
         );
 
+        $db->xdo(
+            delete_from => 'updates',
+            where       => { id => $info->{update_id} },
+        );
+
         print "Dropped: $info->{kind} $info->{id}.$info->{update_id}\n";
         $ctx->ok( 'Drop' . ucfirst( $info->{kind} ) . 'Update', $info );
     }
     else {
+        $ctx->update_repo(
+            {
+                message => 'drop ' . $info->{kind} . ' ' . $info->{id},
+            }
+        );
 
         $db->xdo(
             delete_from => $info->{kind} . 's',
             where       => { id => $info->{id} },
         );
 
-        $db->update_repo(
-            {
-                author  => $ctx->{user}->{name},
-                email   => $ctx->{user}->{email},
-                message => 'drop ' . $info->{kind} . ' ' . $info->{id},
-            }
-        );
-
         print "Dropped: $info->{kind} $info->{id}\n";
         $ctx->ok( 'Drop' . ucfirst( $info->{kind} ), $info );
     }
@@ -72,7 +61,7 @@ bif-drop - delete a topic or topic update
 
 =head1 VERSION
 
-0.1.0_18 (2014-05-04)
+0.1.0_19 (2014-05-08)
 
 =head1 SYNOPSIS
 
