@@ -6,7 +6,7 @@ use AnyEvent;
 use Bif::Client;
 use Coro;
 
-our $VERSION = '0.1.0_18';
+our $VERSION = '0.1.0_19';
 
 sub run {
     my $ctx = shift;
@@ -19,10 +19,6 @@ sub run {
     my @pinfo;
     foreach my $path ( @{ $ctx->{path} } ) {
         my $pinfo = $ctx->get_project($path);
-
-        return $ctx->err( 'ProjectNotFound', 'project not found: %s', $path )
-          unless $pinfo;
-
         push( @pinfo, $pinfo );
     }
 
@@ -34,7 +30,8 @@ sub run {
 
     my @new_pinfo;
     foreach my $pinfo (@pinfo) {
-        my $exists = $ctx->get_project( $pinfo->{path}, $hub->{alias} );
+        my $exists =
+          eval { $ctx->get_project( $pinfo->{path}, $hub->{alias} ) };
 
         if ($exists) {
             if ( $exists->{uuid} eq $pinfo->{uuid} ) {
@@ -84,10 +81,8 @@ sub run {
         eval {
             $db->txn(
                 sub {
-                    $db->update_repo(
+                    $ctx->update_repo(
                         {
-                            author            => $ctx->{user}->{name},
-                            email             => $ctx->{user}->{email},
                             related_update_id => $ctx->{update_id},
                             message =>
                               "export @{$ctx->{path}} $hub->{location}",
@@ -183,7 +178,11 @@ sub run {
             );
         };
 
-        $error .= $@ if $@;
+        if ($@) {
+            $error .= $@;
+            print "\n";
+        }
+
         $client->disconnect;
         return $cv->send( !$error );
     };
@@ -204,7 +203,7 @@ bif-export -  export a project to a remote hub
 
 =head1 VERSION
 
-0.1.0_18 (2014-05-04)
+0.1.0_19 (2014-05-08)
 
 =head1 SYNOPSIS
 
