@@ -1,6 +1,6 @@
 CREATE TABLE func_update_task(
+    update_id INTEGER NOT NULL,
     id INTEGER NOT NULL,
-    update_id INTEGER NOT NULL DEFAULT (currval('updates')),
     status_id INTEGER,
     title VARCHAR
 );
